@@ -18,22 +18,13 @@ import pandas as pd
 import spacy
 from spacy.matcher import Matcher
 from nlprule import Tokenizer, Rules
-from tqdm import tqdm
 tokenizer = Tokenizer.load("en")
 rules = Rules.load("en", tokenizer)
 
 NLP = spacy.load('en_core_web_sm', disable = ['parser','ner'])
-PLACEHOLDER = {'PLACEHOLDER': 'PLACEHOLDER'}
-LXNET_PATHS = {
-    'Dictionary': 'lxnet_dictionary_v.1.0.0.json',
-    'Example_Sentences': 'lxnet_example_v.1.0.0.json',
-    'Difficulty': 'lxnet_difficulty_v.1.0.0.json',
-    'Mapper': 'sensekey_map_v.1.0.0.json',
-    'Original_DB': "original_DB_map_v.1.0.0.json"
-}
 
 """
-locate_elements_from_WN_data_line (function)
+bracket_remover (function)
 
 description:
 워드넷 data 파일에는 ready_to_hand(p)와 같은 단어들이 있는데, (p)를 제거하는 역할을 한다. 이외 bracket안에 있는것은 두 단계까지 제거 가능하다.
@@ -426,6 +417,7 @@ def change_wn_sense_ids_to_wn_sense_keys(
 
 
 """
+(사용하지 않음)
 add_grade_frequency_and_KoDef (function)
 
 description:
@@ -440,7 +432,8 @@ output:
 """
 def add_grade_frequency_and_KoDef(
     changed_instances: list,
-    original_db: object
+    original_db: object,
+    create_version: str = '1.0.2',
     ) -> list :
     added_instances = []
 
@@ -484,8 +477,12 @@ def add_grade_frequency_and_KoDef(
         else:
             original_db_en_def = None
 
-        EnDef = changed_instance['enDef'].replace(";","")
-        EnDef = EnDef.strip()
+        if create_version == '1.0.0':
+            EnDef = changed_instance['enDef'].replace(";","")
+            EnDef = EnDef.strip()
+        elif create_version == '1.0.2': # 1.0.0 버전에는 ;가 모두 사라지는 문제가 있어서 변경
+            EnDef = ''.join(changed_instance['enDef'].rsplit(';', 1))
+            EnDef = EnDef.strip()
 
         added_instances.append(
             {
@@ -523,7 +520,8 @@ output:
     example_mapped_instances: list
 """
 def map_and_create_example_sentences_database(
-    preprocessed_instances: list
+    preprocessed_instances: list,
+    create_version: str = '1.0.2'
     ) -> list :
     example_mapped_instances = []
     example_sentences_list = []
@@ -542,20 +540,39 @@ def map_and_create_example_sentences_database(
                     'end': specific_location[1]
                 }
                 location_dict_list.append(location_dict)
-            example_id_dictionary = {
-                'example_id': example_id,
-                'start': example_sentence["target_word_location"][0],
-                'end': example_sentence["target_word_location"][1],
-                'locations': location_dict_list
-            }
-            preprocessed_instance_example_id.append(example_id_dictionary)
-            example_sentences_list.append(
-                {   
+            if create_version == '1.0.0':
+                example_id_dictionary = {
                     'example_id': example_id,
-                    'sentence': example_sentence["example_sentence"],
-                    'source': 'wordnet3.0'
+                    'start': example_sentence["target_word_location"][0],
+                    'end': example_sentence["target_word_location"][1],
+                    'locations': location_dict_list
                 }
-            )
+                preprocessed_instance_example_id.append(example_id_dictionary)
+                example_sentences_list.append(
+                    {   
+                        'example_id': example_id,
+                        'sentence': example_sentence["example_sentence"],
+                        'source': 'wordnet3.0'
+                    }
+                )
+            elif create_version == '1.0.2':
+                example_id_dictionary = {
+                    'example_id': example_id,
+                    'start': example_sentence["target_word_location"][0],
+                    'end': example_sentence["target_word_location"][1],
+                    'locations': location_dict_list,
+                    "eff_date":"2022-12-19T00:00:00+09:00"
+                }
+                preprocessed_instance_example_id.append(example_id_dictionary)
+                example_sentences_list.append(
+                    {   
+                        'example_id': example_id,
+                        'sentence': example_sentence["example_sentence"],
+                        'source': 'wordnet3.0',
+                        "eff_date":"2022-12-19T00:00:00+09:00",
+                        "end_date":None
+                    }
+                )
         example_mapped_instances.append(
             {
                 "word" : preprocessed_instance['word'] ,
@@ -798,13 +815,13 @@ output:
     id_key_mapper: object
     original_db: object
 """
-def load_necessary_resources() -> tuple[object, object, object]:
+def load_necessary_resources(original_db_path: str, wn_sense_ids_to_wn_sense_keys_path: str) -> tuple[object, object, object]:
     id_key_mapper =\
-        pd.read_csv(f'resources/wn_sense_ids_to_wn_sense_keys.txt', sep=" ", header=None)
+        pd.read_csv(f'{wn_sense_ids_to_wn_sense_keys_path}', sep=" ", header=None)
     id_key_mapper.columns = ["wn_sense_key", "wn_sense_id", "ranking", "1"]
 
     original_db =\
-        pd.read_csv('resources/original_db.csv', sep=",", header=None)
+        pd.read_csv(f'{original_db_path}', sep=",", header=None)
     original_db.columns = ["0", "1", "priority", "3", "grade", "KoDef","original_db_en_def", "wn_sense_key", "8", "9", "10", "11", "12", "13", "14", "15"]
 
     return id_key_mapper, original_db
@@ -823,16 +840,30 @@ input:
 output:
     None
 """
-def create_lxnet_from_WN():
-    id_key_mapper, original_db = load_necessary_resources()
+def create_lxnet_from_WN(wordnet_db_path: str, original_db_path: str, wn_sense_ids_to_wn_sense_keys_path: str, lxnet_paths: dict):
+    id_key_mapper, original_db = load_necessary_resources(original_db_path, wn_sense_ids_to_wn_sense_keys_path)
     preprocessed_instances = []
     start_time = time.time()
+    
+    global LXNET_PATHS
+    LXNET_PATHS = lxnet_paths
 
-    for pos in tqdm(['verb','adj','adv','noun']):
+    for pos in ['verb','adj','adv','noun']:
         count = 0
-        with open(f'resources/wordnet3.0_db/data.{pos}', 'r') as pos_file:
+        with open(f'{wordnet_db_path}/data.{pos}', 'r') as pos_file:
             while True:
+
                 count += 1
+                if pos == 'adj':
+                    total_count = 18186
+                elif pos == 'adv':
+                    total_count = 3651
+                elif pos == 'noun':
+                    total_count = 82145
+                elif pos == 'verb':
+                    total_count = 13797 
+                if count % 50 == 0:
+                    print(f'{count} out of {total_count} | time taken: {time.time()-start_time}')
 
                 WN_data_line = pos_file.readline()
 
@@ -890,12 +921,11 @@ def create_lxnet_from_WN():
     print(f"save time: {time.time()-start_time}")
     print("SUCCESS!")
 
-if __name__ == '__main__':
-    create_lxnet_from_WN()
 
 
 
 """
+(사용하지 않음)
 inflate_with_example_sentences_semcor_and_omsti (function)
 
 description:
@@ -908,7 +938,7 @@ input:
 output:
     inflated_instances: list
 """
-def inflate_with_example_sentences_semcor_and_omsti(
+def xxxinflate_with_example_sentences_semcor_and_omsti(
     added_instances: list,
     raganato_gold: object
     ) -> list:
@@ -1015,6 +1045,7 @@ def inflate_with_example_sentences_semcor_and_omsti(
     return inflated_instances
 
 """
+(사용하지 않음)
 load_necessary_resources (function)
 
 description:
@@ -1028,7 +1059,7 @@ output:
     original_db: object
     raganato_gold: object
 """
-def load_necessary_resources() -> tuple[object, object, object]:
+def xxxload_necessary_resources() -> tuple[object, object, object]:
     id_key_mapper =\
         pd.read_csv(f'resources/wn_sense_ids_to_wn_sense_keys.txt', sep=" ", header=None)
     id_key_mapper.columns = ["wn_sense_key", "wn_sense_id", "0", "1"]
